ams.core.service.NumExpandDim
=============================

.. currentmodule:: ams.core.service

.. autoclass:: NumExpandDim

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~NumExpandDim.assign_memory
       
       
          ~NumExpandDim.evaluate
       
       
          ~NumExpandDim.get_names
       
       
          ~NumExpandDim.parse
       
       
          ~NumExpandDim.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~NumExpandDim.class_name
      ~NumExpandDim.n
      ~NumExpandDim.shape
      ~NumExpandDim.size
      ~NumExpandDim.v
      ~NumExpandDim.v0
      ~NumExpandDim.v1
   
   